# Flatnotes: Simple Markdown Note-Taking

Flatnotes is a straightforward, self-hosted, markdown-based note-taking application. It's designed for simplicity and efficiency, allowing you to quickly capture ideas, draft content, and organize your notes. A key feature in the Changemaker context is its potential to directly feed into your blog or documentation.

## Key Features

*   **Markdown First**: Write notes using the familiar and versatile Markdown syntax.
*   **Live Preview**: (Often a feature) See how your Markdown will render as you type.
*   **Tagging/Organization**: Organize notes with tags or a folder-like structure.
*   **Search**: Quickly find the information you need within your notes.
*   **Automatic Saving**: Reduces the risk of losing work.
*   **Simple Interface**: Distraction-free writing environment.
*   **Self-Hosted**: Your notes remain private on your server.
*   **Potential Blog Integration**: Notes can be easily copied or potentially directly published to your MkDocs site or other blog platforms that use Markdown.

## Getting Started with Flatnotes

### Accessing Flatnotes
1.  **URL**: Access Flatnotes locally via `http://localhost:8089/` (or your configured external URL).
2.  **Login**: Flatnotes will have its own authentication. You should have set up credentials during the Changemaker installation or the first time you accessed Flatnotes.

### Basic Usage

1.  **Creating a New Note**:
    *   Look for a "New Note" button or similar interface element.
    *   Give your note a title.
    *   Start typing your content in Markdown in the main editor pane.

2.  **Writing in Markdown**:
    *   Use standard Markdown syntax for headings, lists, bold/italic text, links, images, code blocks, etc.
    *   Example:
        ```markdown
        # My Awesome Idea

        This is a *brilliant* idea that I need to remember.

        ## Steps
        1. Draft initial thoughts.
        2. Research more.
        3. Write a blog post.

        [Link to relevant site](https://example.com)
        ```

3.  **Saving Notes**:
    *   Flatnotes typically saves your notes automatically as you type or when you switch to another note.

4.  **Organizing Notes**:
    *   Explore options for tagging your notes or organizing them into categories/folders if the interface supports it. This helps in managing a large number of notes.

5.  **Searching Notes**:
    *   Use the search bar to find notes based on keywords in their title or content.

### Using Flatnotes for Blog/Documentation Content

Flatnotes is excellent for drafting content that will eventually become part of your MkDocs site:

1.  **Draft Your Article/Page**: Write the full content in Flatnotes, focusing on the text and structure.
2.  **Copy Markdown**: Once you're satisfied, select all the text in your note and copy it.
3.  **Create/Edit MkDocs File**: 
    *   Go to Code Server.
    *   Navigate to your `mkdocs/docs/` directory (or a subdirectory like `blog/posts/`).
    *   Create a new `.md` file or open an existing one.
    *   Paste the Markdown content you copied from Flatnotes.
4.  **Save and Preview**: Save the file in Code Server. If `mkdocs serve` is running, your site will update, and you can preview the new content.

## Further Information

For more specific details on Flatnotes features, customization, or troubleshooting, refer to the [official Flatnotes Documentation](https://github.com/Dullage/Flatnotes) (as it's a GitHub-hosted project, the README and repository wiki are the primary sources of documentation).
