# NocoDB: Open Source Airtable Alternative

NocoDB is a powerful open-source alternative to services like Airtable. It allows you to turn various types of SQL databases (like MySQL, PostgreSQL, SQL Server, SQLite) into a smart spreadsheet interface. This makes data management, collaboration, and even building simple applications much more accessible without extensive coding.

## Key Features

*   **Spreadsheet Interface**: View and manage your database tables like a spreadsheet.
*   **Multiple View Types**: Beyond grids, create Kanban boards, forms, galleries, and calendar views from your data.
*   **Connect to Existing Databases**: Bring your existing SQL databases into NocoDB or create new ones from scratch.
*   **API Access**: NocoDB automatically generates REST APIs for your tables, enabling integration with other applications and services.
*   **Collaboration**: Share bases and tables with team members with granular permission controls.
*   **App Store / Integrations**: Extend functionality with built-in or third-party apps and integrations.
*   **Self-Hosted**: Maintain full control over your data and infrastructure.
*   **No-Code/Low-Code**: Build simple applications and workflows with minimal to no coding.

## Getting Started with NocoDB

### Accessing NocoDB
1.  **URL**: Access NocoDB locally via `http://localhost:8090/` (or your configured external URL).
2.  **Initial Setup / Login**: 
    *   The first time you access NocoDB, you might be guided through a setup process to create an initial super admin user.
    *   For subsequent access, you'll log in with these credentials.

### Basic Workflow

1.  **Understanding the Interface**:
    *   **Workspace/Projects (or Bases)**: NocoDB organizes data into projects or bases, similar to Airtable bases. Each project can contain multiple tables.
    *   **Tables**: These are your database tables, displayed in a spreadsheet-like grid by default.
    *   **Views**: For each table, you can create multiple views (Grid, Form, Kanban, Gallery, Calendar) to visualize and interact with the data in different ways.

2.  **Creating a New Project/Base**:
    *   Look for an option like "New Project" or "Create Base".
    *   You might be asked to connect to an existing database or create a new one (often SQLite by default for ease of use if not connecting to an external DB).

3.  **Creating a Table**:
    *   Within a project, create new tables.
    *   Define columns (fields) for your table, specifying the data type for each (e.g., Text, Number, Date, Email, Select, Attachment, Formula, Link to Another Record).

4.  **Adding and Editing Data**:
    *   Click into cells in the grid view to add or edit data, just like a spreadsheet.
    *   Use forms (if you create a form view) for more structured data entry.

5.  **Creating Different Views**:
    *   For any table, click on the view switcher (often near the table name) and select "Create View".
    *   Choose the view type (e.g., Kanban).
    *   Configure the view (e.g., for Kanban, select the single-select field that will define the columns/stacks).

6.  **Linking Tables (Relational Data)**:
    *   Use the "Link to Another Record" field type to create relationships between tables (e.g., link a `Tasks` table to a `Projects` table).
    *   This allows you to look up and display related data across tables.

7.  **Using Formulas**:
    *   Create formula fields to compute values based on other fields in the same table, similar to spreadsheet formulas.

8.  **Exploring APIs**:
    *   NocoDB automatically provides REST API endpoints for your tables. Look for an "API Docs" or similar section to explore these APIs, which can be used to integrate NocoDB data with other applications (e.g., your website, automation scripts).

## Use Cases within Changemaker

*   **Content Management**: Manage structured content for your website or blog (e.g., a list of events, resources, testimonials).
*   **Contact Management/CRM**: Keep track of contacts, leads, or supporters.
*   **Project Management**: Track tasks, projects, and deadlines.
*   **Inventory Management**: If applicable to your campaign or project.
*   **Data Collection**: Use NocoDB forms to collect information.

## Further Information

NocoDB is a feature-rich platform. For detailed guides, tutorials, API documentation, and advanced usage, refer to the [official NocoDB Documentation](https://docs.nocodb.com/).
