# Portainer: Docker Container Management UI

Portainer is a lightweight management UI that allows you to easily manage your Docker environments (or other container orchestrators like Kubernetes). Changemaker V5 runs its applications as Docker containers, and Portainer provides a visual interface to see, manage, and troubleshoot these containers.

## Key Features

*   **Container Management**: View, start, stop, restart, remove, and inspect Docker containers.
*   **Image Management**: Pull, remove, and inspect Docker images.
*   **Volume Management**: Manage Docker volumes used for persistent storage.
*   **Network Management**: Manage Docker networks.
*   **Stacks/Compose**: Deploy and manage multi-container applications defined in Docker Compose files (stacks).
*   **Logs & Stats**: View container logs and resource usage statistics (CPU, memory).
*   **User-Friendly Interface**: Simplifies Docker management for users who may not be comfortable with the command line.
*   **Multi-Environment Support**: Can manage multiple Docker hosts or Kubernetes clusters (though in Changemaker, it's typically managing the local Docker environment).

## Getting Started with Portainer

### Accessing Portainer
1.  **URL**: Access Portainer locally via `http://localhost:9002/` (or your configured external URL).
2.  **Initial Setup/Login**: 
    *   The first time you access Portainer, you will need to set up an administrator account (username and password).
    *   You will then connect Portainer to the Docker environment it should manage. For Changemaker, this is usually the local Docker socket.

### Basic Usage

1.  **Dashboard**: The main dashboard provides an overview of your Docker environment (number of containers, volumes, images, etc.).

2.  **Containers List**: 
    *   Navigate to "Containers" from the sidebar.
    *   You'll see a list of all running and stopped containers (e.g., `code-server`, `flatnotes`, `listmonk`, etc., that make up Changemaker).
    *   **Actions**: For each container, you can perform actions like:
        *   **Logs**: View real-time logs.
        *   **Inspect**: See detailed configuration and state.
        *   **Stats**: View resource usage.
        *   **Console**: Connect to the container's terminal (if supported by the container).
        *   **Stop/Start/Restart/Remove**.

3.  **Images List**: 
    *   Navigate to "Images" to see all Docker images pulled to your server.
    *   You can pull new images from Docker Hub or other registries, or remove unused images.

4.  **Volumes List**: 
    *   Navigate to "Volumes" to see Docker volumes, which are used by Changemaker apps to store persistent data (e.g., your notes in Flatnotes, your Listmonk database).

5.  **Stacks (Docker Compose)**:
    *   Navigate to "Stacks."
    *   Changemaker itself is likely deployed as a stack using its `docker-compose.yml` file. You might see it listed here.
    *   You can add new stacks (deploy other Docker Compose applications) or manage existing ones.

## Use Cases within Changemaker

*   **Monitoring Application Status**: Quickly see if all Changemaker application containers are running.
*   **Viewing Logs**: Troubleshoot issues by checking the logs of specific application containers.
*   **Restarting Applications**: If an application becomes unresponsive, you can try restarting its container via Portainer.
*   **Resource Management**: Check CPU and memory usage of containers if you suspect performance issues.
*   **Advanced Management**: For users comfortable with Docker, Portainer provides an easier interface for tasks that would otherwise require command-line operations.

## Editing the Site

Portainer is for managing the Docker containers that run the applications. It is not used for editing this documentation site. Site editing is done via **Code Server**.

## Further Information

*   **Portainer Official Website**: [https://www.portainer.io/](https://www.portainer.io/)
*   **Portainer Documentation**: [https://docs.portainer.io/](https://docs.portainer.io/)
